Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Encoder ¶
An Encoder implements an encoding format of values to be sent as response to requests on the API endpoints.
type JsonEncoder ¶
type JsonEncoder struct{}
func (JsonEncoder) Encode ¶
func (_ JsonEncoder) Encode(v ...interface{}) ([]byte, error)
jsonEncoder is an Encoder that produces JSON-formatted responses.
Click to show internal directories.
Click to hide internal directories.